@@ -22,17 +22,18 @@ from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OTreeBasedUnsupervisedAlgorithm import H2OTreeBasedUnsupervisedAlgorithm
 from ai.h2o.sparkling.ml.models.H2OIsolationForestMOJOModel import H2OIsolationForestMOJOModel
 from ai.h2o.sparkling.ml.params.H2OIsolationForestParams import H2OIsolationForestParams
-from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
 
 
-class H2OIsolationForest(H2OIsolationForestParams, H2OCommonParams, H2OTreeBasedUnsupervisedAlgorithm):
+class H2OIsolationForest(H2OIsolationForestParams, H2OTreeBasedUnsupervisedAlgorithm):
 
     @keyword_only
     def __init__(self,
                  calibrationDataFrame=None,
                  validationLabelCol="label",
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -71,6 +72,7 @@ class H2OIsolationForest(H2OIsolationForestParams, H2OCommonParams, H2OTreeBased
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OIsolationForest", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
